@@ -114,19 +114,19 @@ sub run
                 #ok $gz->eof() ;
             }
 
-            # Test curruption directly after the header
+            # Test corruption directly after the header
             # In this case the uncompression object will have been created,
             # so need to check that subsequent reads from the object fail
             if ($header_size > 0)
-            {
-                my $lex = new LexFile my $name ;
-                my $input;
-            
+            {            
                 for my $mode (qw(block line para record slurp))
                 {
 
                     title "Corruption after header - Mode $mode, Source $fb, Transparent $trans";
-
+                    
+                    my $lex = new LexFile my $name ;
+                    my $input;
+                
                     my $part = substr($compressed, 0, $header_size);
                     # Append corrupt data
                     $part .= "\xFF" x 100 ;
@@ -188,10 +188,7 @@ sub run
             foreach my $i ($header_size .. length($compressed) - 1 - $trailer_size)
             {
                 next if $i == 0 ;
-
-#                my $lex = new LexFile my $name ;
-#                my $input;
-#            
+         
                 for my $mode (qw(block line))
                 {
 
@@ -230,13 +227,15 @@ sub run
                     }
                     ok $gz->error() ;
                     cmp_ok $gz->errorNo(), '<', 0 ;
-                    ok $gz->eof() ;
+                    # ok $gz->eof() 
+                    #     or die "EOF";
                     $gz->close();
                 }
             }
             
-            # RawDeflate does not have a trailer
+            # RawDeflate and Zstandard do not have a trailer
             next if $CompressClass eq 'IO::Compress::RawDeflate' ;
+            next if $CompressClass eq 'IO::Compress::Zstd' ;
 
             title "Compressed Trailer Truncation";
             foreach my $i (length($compressed) - $trailer_size .. length($compressed) -1 )
